from setuptools import setup

setup(name='ds_distributions',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['ds_distributions'],
      author = 'Dewen Yushu',
      author_email = 'dewenyushu@gmail.com',
      zip_safe=False)
